@@ -14,6 +14,8 @@ BEGIN {
       skip_interactive
       skip_old_perl
       skip_no_file_which
+      skip_not_in_path
+      is_no
       is_yes
       perl_exe
       perl_path
@@ -33,11 +35,24 @@ sub skip_no_file_which {
   skip "This test requires File::Which.", 1 if not eval { require File::Which };
 }
 
+sub skip_not_in_path {
+  # Test that the specified executable can be found in the PATH environment
+  # variable using File::Which.
+  my $exe = shift; 
+  my $loc = File::Which::which($exe);
+  skip "Executable '$exe' is not in PATH.", 1 if not defined $loc;
+}
+
 sub is_yes {
   my ($val) = @_;
   return ($val =~ /^y(?:es)?/i || $val eq '');
 }
 
+sub is_no {
+  my ($val) = @_;
+  return ($val =~ /^n(?:o)?/i || $val eq '');
+}
+
 sub perl_exe {
   # Find the Perl executable name
   my $this_perl = $^X;
